@@ -60,7 +60,7 @@ makron_taunt(edict_t *self)
 }
 
 /* stand */
-mframe_t makron_frames_stand[] = {
+static mframe_t makron_frames_stand[] = {
 	{ai_stand, 0, NULL},
 	{ai_stand, 0, NULL},
 	{ai_stand, 0, NULL},
@@ -141,7 +141,7 @@ makron_stand(edict_t *self)
 	self->monsterinfo.currentmove = &makron_move_stand;
 }
 
-mframe_t makron_frames_run[] = {
+static mframe_t makron_frames_run[] = {
 	{ai_run, 3, makron_step_left},
 	{ai_run, 12, NULL},
 	{ai_run, 8, NULL},
@@ -227,19 +227,6 @@ makron_prerailgun(edict_t *self)
 	gi.sound(self, CHAN_WEAPON, sound_prerailgun, 1, ATTN_NORM, 0);
 }
 
-mframe_t makron_frames_walk[] = {
-	{ai_walk, 3, makron_step_left},
-	{ai_walk, 12, NULL},
-	{ai_walk, 8, NULL},
-	{ai_walk, 8, NULL},
-	{ai_walk, 8, makron_step_right},
-	{ai_walk, 6, NULL},
-	{ai_walk, 12, NULL},
-	{ai_walk, 9, NULL},
-	{ai_walk, 6, NULL},
-	{ai_walk, 12, NULL}
-};
-
 mmove_t makron_move_walk = {
 	FRAME_walk204,
    	FRAME_walk213,
@@ -276,7 +263,7 @@ makron_run(edict_t *self)
 	}
 }
 
-mframe_t makron_frames_pain6[] = {
+static mframe_t makron_frames_pain6[] = {
 	{ai_move, 0, NULL},
 	{ai_move, 0, NULL},
 	{ai_move, 0, NULL},
@@ -313,7 +300,7 @@ mmove_t makron_move_pain6 = {
    	makron_run
 };
 
-mframe_t makron_frames_pain5[] = {
+static mframe_t makron_frames_pain5[] = {
 	{ai_move, 0, NULL},
 	{ai_move, 0, NULL},
 	{ai_move, 0, NULL},
@@ -327,7 +314,7 @@ mmove_t makron_move_pain5 = {
    	makron_run
 };
 
-mframe_t makron_frames_pain4[] = {
+static mframe_t makron_frames_pain4[] = {
 	{ai_move, 0, NULL},
 	{ai_move, 0, NULL},
 	{ai_move, 0, NULL},
@@ -341,7 +328,7 @@ mmove_t makron_move_pain4 = {
    	makron_run
 };
 
-mframe_t makron_frames_death2[] = {
+static mframe_t makron_frames_death2[] = {
 	{ai_move, -15, NULL},
 	{ai_move, 3, NULL},
 	{ai_move, -12, NULL},
@@ -446,7 +433,7 @@ mmove_t makron_move_death2 = {
    	makron_dead
 };
 
-mframe_t makron_frames_death3[] = {
+static mframe_t makron_frames_death3[] = {
 	{ai_move, 0, NULL},
 	{ai_move, 0, NULL},
 	{ai_move, 0, NULL},
@@ -476,7 +463,7 @@ mmove_t makron_move_death3 = {
    	NULL
 };
 
-mframe_t makron_frames_sight[] = {
+static mframe_t makron_frames_sight[] = {
 	{ai_move, 0, NULL},
 	{ai_move, 0, NULL},
 	{ai_move, 0, NULL},
@@ -524,7 +511,7 @@ makronBFG(edict_t *self)
 	monster_fire_bfg(self, start, dir, 50, 300, 100, 300, MZ2_MAKRON_BFG);
 }
 
-mframe_t makron_frames_attack3[] = {
+static mframe_t makron_frames_attack3[] = {
 	{ai_charge, 0, NULL},
 	{ai_charge, 0, NULL},
 	{ai_charge, 0, NULL},
@@ -542,7 +529,7 @@ mmove_t makron_move_attack3 = {
    	makron_run
 };
 
-mframe_t makron_frames_attack4[] = {
+static mframe_t makron_frames_attack4[] = {
 	{ai_charge, 0, NULL},
 	{ai_charge, 0, NULL},
 	{ai_charge, 0, NULL},
@@ -578,7 +565,7 @@ mmove_t makron_move_attack4 = {
    	makron_run
 };
 
-mframe_t makron_frames_attack5[] = {
+static mframe_t makron_frames_attack5[] = {
 	{ai_charge, 0, makron_prerailgun},
 	{ai_charge, 0, NULL},
 	{ai_charge, 0, NULL},
