@@ -1,4 +1,23 @@
-/* =======================================================================
+/*
+ * Copyright (C) 1997-2001 Id Software, Inc.
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or (at
+ * your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ *
+ * See the GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
+ * 02111-1307, USA.
+ *
+ * =======================================================================
  *
  * Soldier aka "Guard". This is the most complex enemy in Quake 2, since
  * it uses all AI features (dodging, sight, crouching, etc) and comes
@@ -21,6 +40,10 @@ static int sound_death_light;
 static int sound_death;
 static int sound_death_ss;
 static int sound_cock;
+static int sound_step;
+static int sound_step2;
+static int sound_step3;
+static int sound_step4;
 
 void soldier_duck_up(edict_t *self);
 void soldier_stand(edict_t *self);
@@ -28,6 +51,42 @@ void soldier_run(edict_t *self);
 void soldier_fire(edict_t *self, int);
 void soldier_blind(edict_t *self);
 
+void
+soldier_footstep(edict_t *self)
+{
+	if (!g_monsterfootsteps->value)
+		return;
+
+	// Lazy loading for savegame compatibility.
+	if (sound_step == 0 || sound_step2 == 0 || sound_step3 == 0 || sound_step4 == 0)
+	{
+		sound_step = gi.soundindex("player/step1.wav");
+		sound_step2 = gi.soundindex("player/step2.wav");
+		sound_step3 = gi.soundindex("player/step3.wav");
+		sound_step4 = gi.soundindex("player/step4.wav");
+	}
+
+	int i;
+	i = randk() % 4;
+
+	if (i == 0)
+	{
+		gi.sound(self, CHAN_BODY, sound_step, 1, ATTN_NORM, 0);
+	}
+	else if (i == 1)
+	{
+		gi.sound(self, CHAN_BODY, sound_step2, 1, ATTN_NORM, 0);
+	}
+	else if (i == 2)
+	{
+		gi.sound(self, CHAN_BODY, sound_step3, 1, ATTN_NORM, 0);
+	}
+	else if (i == 3)
+	{
+		gi.sound(self, CHAN_BODY, sound_step4, 1, ATTN_NORM, 0);
+	}
+}
+
 void
 soldier_start_charge(edict_t *self)
 {
@@ -50,6 +109,7 @@ soldier_stop_charge(edict_t *self)
 	self->monsterinfo.aiflags &= ~AI_CHARGING;
 }
 
+
 void
 soldier_idle(edict_t *self)
 {
@@ -82,7 +142,7 @@ soldier_cock(edict_t *self)
 	}
 }
 
-mframe_t soldier_frames_stand1[] = {
+static mframe_t soldier_frames_stand1[] = {
 	{ai_stand, 0, soldier_idle},
 	{ai_stand, 0, NULL},
 	{ai_stand, 0, NULL},
@@ -117,14 +177,15 @@ mframe_t soldier_frames_stand1[] = {
 	{ai_stand, 0, NULL}
 };
 
-mmove_t soldier_move_stand1 = {
+mmove_t soldier_move_stand1 =
+{
 	FRAME_stand101,
    	FRAME_stand130,
-   	soldier_frames_stand1,
-   	soldier_stand
+	soldier_frames_stand1,
+	soldier_stand
 };
 
-mframe_t soldier_frames_stand3[] = {
+static mframe_t soldier_frames_stand3[] = {
 	{ai_stand, 0, NULL},
 	{ai_stand, 0, NULL},
 	{ai_stand, 0, NULL},
@@ -169,7 +230,8 @@ mframe_t soldier_frames_stand3[] = {
 	{ai_stand, 0, NULL}
 };
 
-mmove_t soldier_move_stand3 = {
+mmove_t soldier_move_stand3 =
+{
 	FRAME_stand301,
    	FRAME_stand339,
    	soldier_frames_stand3,
@@ -209,16 +271,16 @@ soldier_walk1_random(edict_t *self)
 	}
 }
 
-mframe_t soldier_frames_walk1[] = {
+static mframe_t soldier_frames_walk1[] = {
 	{ai_walk, 3, NULL},
 	{ai_walk, 6, NULL},
 	{ai_walk, 2, NULL},
-	{ai_walk, 2, NULL},
+	{ai_walk, 2, soldier_footstep},
 	{ai_walk, 2, NULL},
 	{ai_walk, 1, NULL},
 	{ai_walk, 6, NULL},
 	{ai_walk, 5, NULL},
-	{ai_walk, 3, NULL},
+	{ai_walk, 3, soldier_footstep},
 	{ai_walk, -1, soldier_walk1_random},
 	{ai_walk, 0, NULL},
 	{ai_walk, 0, NULL},
@@ -245,19 +307,20 @@ mframe_t soldier_frames_walk1[] = {
 	{ai_walk, 0, NULL}
 };
 
-mmove_t soldier_move_walk1 = {
+mmove_t soldier_move_walk1 =
+{
 	FRAME_walk101,
-   	FRAME_walk133,
-   	soldier_frames_walk1,
-   	NULL
+	FRAME_walk133,
+	soldier_frames_walk1,
+	NULL
 };
 
-mframe_t soldier_frames_walk2[] = {
-	{ai_walk, 4, NULL},
+static mframe_t soldier_frames_walk2[] = {
+	{ai_walk, 4, soldier_footstep},
 	{ai_walk, 4, NULL},
 	{ai_walk, 9, NULL},
 	{ai_walk, 8, NULL},
-	{ai_walk, 5, NULL},
+	{ai_walk, 5, soldier_footstep},
 	{ai_walk, 1, NULL},
 	{ai_walk, 3, NULL},
 	{ai_walk, 7, NULL},
@@ -265,10 +328,11 @@ mframe_t soldier_frames_walk2[] = {
 	{ai_walk, 7, NULL}
 };
 
-mmove_t soldier_move_walk2 = {
+mmove_t soldier_move_walk2 =
+{
 	FRAME_walk209,
    	FRAME_walk218,
-   	soldier_frames_walk2,
+	soldier_frames_walk2,
    	NULL
 };
 
@@ -290,12 +354,13 @@ soldier_walk(edict_t *self)
 	}
 }
 
-mframe_t soldier_frames_start_run[] = {
+static mframe_t soldier_frames_start_run[] = {
 	{ai_run, 7, NULL},
 	{ai_run, 5, NULL}
 };
 
-mmove_t soldier_move_start_run = {
+mmove_t soldier_move_start_run =
+{
 	FRAME_run01,
    	FRAME_run02,
    	soldier_frames_start_run,
@@ -316,19 +381,20 @@ soldier_fire_run(edict_t *self)
 	}
 }
 
-mframe_t soldier_frames_run[] = {
+static mframe_t soldier_frames_run[] = {
 	{ai_run, 10, NULL},
-	{ai_run, 11, NULL},
+	{ai_run, 11, soldier_footstep},
 	{ai_run, 11, NULL},
 	{ai_run, 16, NULL},
-	{ai_run, 10, NULL},
+	{ai_run, 10, soldier_footstep},
 	{ai_run, 15, NULL}
 };
 
-mmove_t soldier_move_run = {
+mmove_t soldier_move_run =
+{
 	FRAME_run03,
-   	FRAME_run08,
-   	soldier_frames_run,
+	FRAME_run08,
+	soldier_frames_run,
    	NULL
 };
 
@@ -360,7 +426,7 @@ soldier_run(edict_t *self)
 	}
 }
 
-mframe_t soldier_frames_pain1[] = {
+static mframe_t soldier_frames_pain1[] = {
 	{ai_move, -3, NULL},
 	{ai_move, 4, NULL},
 	{ai_move, 1, NULL},
@@ -368,14 +434,15 @@ mframe_t soldier_frames_pain1[] = {
 	{ai_move, 0, NULL}
 };
 
-mmove_t soldier_move_pain1 = {
+mmove_t soldier_move_pain1 =
+{
 	FRAME_pain101,
    	FRAME_pain105,
    	soldier_frames_pain1,
    	soldier_run
 };
 
-mframe_t soldier_frames_pain2[] = {
+static mframe_t soldier_frames_pain2[] = {
 	{ai_move, -13, NULL},
 	{ai_move, -1, NULL},
 	{ai_move, 2, NULL},
@@ -385,17 +452,18 @@ mframe_t soldier_frames_pain2[] = {
 	{ai_move, 2, NULL}
 };
 
-mmove_t soldier_move_pain2 = {
+mmove_t soldier_move_pain2 =
+{
 	FRAME_pain201,
-   	FRAME_pain207,
+	FRAME_pain207,
    	soldier_frames_pain2,
    	soldier_run
 };
 
-mframe_t soldier_frames_pain3[] = {
+static mframe_t soldier_frames_pain3[] = {
 	{ai_move, -8, NULL},
 	{ai_move, 10, NULL},
-	{ai_move, -4, NULL},
+	{ai_move, -4, soldier_footstep},
 	{ai_move, -1, NULL},
 	{ai_move, -3, NULL},
 	{ai_move, 0, NULL},
@@ -410,17 +478,18 @@ mframe_t soldier_frames_pain3[] = {
 	{ai_move, 2, NULL},
 	{ai_move, 4, NULL},
 	{ai_move, 3, NULL},
-	{ai_move, 2, NULL}
+	{ai_move, 2, soldier_footstep}
 };
 
-mmove_t soldier_move_pain3 = {
+mmove_t soldier_move_pain3 =
+{
 	FRAME_pain301,
    	FRAME_pain318,
    	soldier_frames_pain3,
    	soldier_run
 };
 
-mframe_t soldier_frames_pain4[] = {
+static mframe_t soldier_frames_pain4[] = {
 	{ai_move, 0, NULL},
 	{ai_move, 0, NULL},
 	{ai_move, 0, NULL},
@@ -440,15 +509,17 @@ mframe_t soldier_frames_pain4[] = {
 	{ai_move, 0, NULL}
 };
 
-mmove_t soldier_move_pain4 = {
+mmove_t soldier_move_pain4 =
+{
 	FRAME_pain401,
-   	FRAME_pain417,
-   	soldier_frames_pain4,
+	FRAME_pain417,
+	soldier_frames_pain4,
    	soldier_run
 };
 
 void
-soldier_pain(edict_t *self, edict_t *other /* unused */, float kick, int damage)
+soldier_pain(edict_t *self, edict_t *other /* unused */,
+		float kick /* unused */, int damage /* unused */)
 {
 	float r;
 	int n;
@@ -473,8 +544,8 @@ soldier_pain(edict_t *self, edict_t *other /* unused */, float kick, int damage)
 	{
 		if ((self->velocity[2] > 100) &&
 			((self->monsterinfo.currentmove == &soldier_move_pain1) ||
-		 (self->monsterinfo.currentmove == &soldier_move_pain2) ||
-		 (self->monsterinfo.currentmove == &soldier_move_pain3)))
+			 (self->monsterinfo.currentmove == &soldier_move_pain2) ||
+			 (self->monsterinfo.currentmove == &soldier_move_pain3)))
 		{
 			/* clear duck flag */
 			if (self->monsterinfo.aiflags & AI_DUCKED)
@@ -545,20 +616,40 @@ soldier_pain(edict_t *self, edict_t *other /* unused */, float kick, int damage)
 }
 
 static int blaster_flash[] =
-{MZ2_SOLDIER_BLASTER_1, MZ2_SOLDIER_BLASTER_2, MZ2_SOLDIER_BLASTER_3,
- MZ2_SOLDIER_BLASTER_4, MZ2_SOLDIER_BLASTER_5, MZ2_SOLDIER_BLASTER_6,
- MZ2_SOLDIER_BLASTER_7, MZ2_SOLDIER_BLASTER_8};
+{
+	MZ2_SOLDIER_BLASTER_1,
+   	MZ2_SOLDIER_BLASTER_2,
+   	MZ2_SOLDIER_BLASTER_3,
+	MZ2_SOLDIER_BLASTER_4,
+	MZ2_SOLDIER_BLASTER_5,
+	MZ2_SOLDIER_BLASTER_6,
+	MZ2_SOLDIER_BLASTER_7,
+   	MZ2_SOLDIER_BLASTER_8
+};
 
 static int shotgun_flash[] =
-{MZ2_SOLDIER_SHOTGUN_1, MZ2_SOLDIER_SHOTGUN_2, MZ2_SOLDIER_SHOTGUN_3,
- MZ2_SOLDIER_SHOTGUN_4, MZ2_SOLDIER_SHOTGUN_5, MZ2_SOLDIER_SHOTGUN_6,
- MZ2_SOLDIER_SHOTGUN_7, MZ2_SOLDIER_SHOTGUN_8};
+{
+	MZ2_SOLDIER_SHOTGUN_1,
+	MZ2_SOLDIER_SHOTGUN_2,
+	MZ2_SOLDIER_SHOTGUN_3,
+	MZ2_SOLDIER_SHOTGUN_4,
+	MZ2_SOLDIER_SHOTGUN_5,
+	MZ2_SOLDIER_SHOTGUN_6,
+	MZ2_SOLDIER_SHOTGUN_7,
+	MZ2_SOLDIER_SHOTGUN_8
+};
 
 static int machinegun_flash[] =
-{MZ2_SOLDIER_MACHINEGUN_1, MZ2_SOLDIER_MACHINEGUN_2, MZ2_SOLDIER_MACHINEGUN_3,
- MZ2_SOLDIER_MACHINEGUN_4, MZ2_SOLDIER_MACHINEGUN_5,
- MZ2_SOLDIER_MACHINEGUN_6, MZ2_SOLDIER_MACHINEGUN_7,
- MZ2_SOLDIER_MACHINEGUN_8};
+{
+	MZ2_SOLDIER_MACHINEGUN_1,
+	MZ2_SOLDIER_MACHINEGUN_2,
+	MZ2_SOLDIER_MACHINEGUN_3,
+	MZ2_SOLDIER_MACHINEGUN_4,
+	MZ2_SOLDIER_MACHINEGUN_5,
+	MZ2_SOLDIER_MACHINEGUN_6,
+	MZ2_SOLDIER_MACHINEGUN_7,
+	MZ2_SOLDIER_MACHINEGUN_8
+};
 
 void
 soldier_fire(edict_t *self, int in_flash_number)
@@ -779,7 +870,7 @@ soldier_attack1_refire2(edict_t *self)
 	}
 }
 
-mframe_t soldier_frames_attack1[] = {
+static mframe_t soldier_frames_attack1[] = {
 	{ai_charge, 0, NULL},
 	{ai_charge, 0, NULL},
 	{ai_charge, 0, soldier_fire1},
@@ -794,10 +885,11 @@ mframe_t soldier_frames_attack1[] = {
 	{ai_charge, 0, NULL}
 };
 
-mmove_t soldier_move_attack1 = {
+mmove_t soldier_move_attack1 =
+{
 	FRAME_attak101,
-   	FRAME_attak112,
-   	soldier_frames_attack1,
+	FRAME_attak112,
+	soldier_frames_attack1,
    	soldier_run
 };
 
@@ -835,7 +927,8 @@ soldier_attack2_refire1(edict_t *self)
 		return;
 	}
 
-	if (((skill->value == SKILL_HARDPLUS) && (random() < 0.5)) || (range(self, self->enemy) == RANGE_MELEE))
+	if (((skill->value == SKILL_HARDPLUS) &&
+		 (random() < 0.5)) || (range(self, self->enemy) == RANGE_MELEE))
 	{
 		self->monsterinfo.nextframe = FRAME_attak204;
 	}
@@ -868,13 +961,14 @@ soldier_attack2_refire2(edict_t *self)
 		return;
 	}
 
-	if (((skill->value == SKILL_HARDPLUS) && (random() < 0.5)) || (range(self, self->enemy) == RANGE_MELEE))
+	if (((skill->value == SKILL_HARDPLUS) &&
+		 (random() < 0.5)) || (range(self, self->enemy) == RANGE_MELEE))
 	{
 		self->monsterinfo.nextframe = FRAME_attak204;
 	}
 }
 
-mframe_t soldier_frames_attack2[] = {
+static mframe_t soldier_frames_attack2[] = {
 	{ai_charge, 0, NULL},
 	{ai_charge, 0, NULL},
 	{ai_charge, 0, NULL},
@@ -895,7 +989,8 @@ mframe_t soldier_frames_attack2[] = {
 	{ai_charge, 0, NULL}
 };
 
-mmove_t soldier_move_attack2 = {
+mmove_t soldier_move_attack2 =
+{
 	FRAME_attak201,
    	FRAME_attak218,
    	soldier_frames_attack2,
@@ -928,7 +1023,7 @@ soldier_attack3_refire(edict_t *self)
 	}
 }
 
-mframe_t soldier_frames_attack3[] = {
+static mframe_t soldier_frames_attack3[] = {
 	{ai_charge, 0, NULL},
 	{ai_charge, 0, NULL},
 	{ai_charge, 0, soldier_fire3},
@@ -940,11 +1035,12 @@ mframe_t soldier_frames_attack3[] = {
 	{ai_charge, 0, NULL}
 };
 
-mmove_t soldier_move_attack3 = {
+mmove_t soldier_move_attack3 =
+{
 	FRAME_attak301,
-   	FRAME_attak309,
-   	soldier_frames_attack3,
-   	soldier_run
+	FRAME_attak309,
+	soldier_frames_attack3,
+	soldier_run
 };
 
 void
@@ -958,16 +1054,17 @@ soldier_fire4(edict_t *self)
 	soldier_fire(self, 3);
 }
 
-mframe_t soldier_frames_attack4[] = {
-	{ai_charge, 0, NULL},
+static mframe_t soldier_frames_attack4[] = {
 	{ai_charge, 0, NULL},
+	{ai_charge, 0, soldier_footstep},
 	{ai_charge, 0, soldier_fire4},
 	{ai_charge, 0, NULL},
 	{ai_charge, 0, NULL},
-	{ai_charge, 0, NULL}
+	{ai_charge, 0, soldier_footstep}
 };
 
-mmove_t soldier_move_attack4 = {
+mmove_t soldier_move_attack4 =
+{
 	FRAME_attak401,
    	FRAME_attak406,
    	soldier_frames_attack4,
@@ -1018,11 +1115,11 @@ soldier_attack6_refire(edict_t *self)
 	}
 }
 
-mframe_t soldier_frames_attack6[] = {
+static mframe_t soldier_frames_attack6[] = {
 	{ai_run, 10, soldier_start_charge},
 	{ai_run, 4, NULL},
 	{ai_run, 12, soldier_fire8},
-	{ai_run, 11, NULL},
+	{ai_run, 11, soldier_footstep},
 	{ai_run, 13, monster_done_dodge},
 	{ai_run, 18, NULL},
 	{ai_run, 15, NULL},
@@ -1035,11 +1132,12 @@ mframe_t soldier_frames_attack6[] = {
 	{ai_run, 17, soldier_attack6_refire}
 };
 
-mmove_t soldier_move_attack6 = {
+mmove_t soldier_move_attack6 =
+{
 	FRAME_runs01,
-   	FRAME_runs14,
-   	soldier_frames_attack6,
-   	soldier_run
+	FRAME_runs14,
+	soldier_frames_attack6,
+	soldier_run
 };
 
 void
@@ -1152,7 +1250,7 @@ soldier_sight(edict_t *self, edict_t *other /* unused */)
 	}
 }
 
-mframe_t soldier_frames_duck[] = {
+static mframe_t soldier_frames_duck[] = {
 	{ai_move, 5, monster_duck_down},
 	{ai_move, -1, monster_duck_hold},
 	{ai_move, 1, NULL},
@@ -1160,7 +1258,8 @@ mframe_t soldier_frames_duck[] = {
 	{ai_move, 5, NULL}
 };
 
-mmove_t soldier_move_duck = {
+mmove_t soldier_move_duck =
+{
 	FRAME_duck01,
    	FRAME_duck05,
    	soldier_frames_duck,
@@ -1268,7 +1367,7 @@ soldier_dead2(edict_t *self)
 	gi.linkentity(self);
 }
 
-mframe_t soldier_frames_death1[] = {
+static mframe_t soldier_frames_death1[] = {
 	{ai_move, 0, NULL},
 	{ai_move, -10, NULL},
 	{ai_move, -10, NULL},
@@ -1310,14 +1409,15 @@ mframe_t soldier_frames_death1[] = {
 	{ai_move, 0, NULL}
 };
 
-mmove_t soldier_move_death1 = {
+mmove_t soldier_move_death1 =
+{
 	FRAME_death101,
-   	FRAME_death136,
-   	soldier_frames_death1,
-   	soldier_dead
+	FRAME_death136,
+	soldier_frames_death1,
+	soldier_dead
 };
 
-mframe_t soldier_frames_death2[] = {
+static mframe_t soldier_frames_death2[] = {
 	{ai_move, -5, NULL},
 	{ai_move, -5, NULL},
 	{ai_move, -5, NULL},
@@ -1358,14 +1458,15 @@ mframe_t soldier_frames_death2[] = {
 	{ai_move, 0, NULL}
 };
 
-mmove_t soldier_move_death2 = {
+mmove_t soldier_move_death2 =
+{
 	FRAME_death201,
-   	FRAME_death235,
+	FRAME_death235,
    	soldier_frames_death2,
    	soldier_dead
 };
 
-mframe_t soldier_frames_death3[] = {
+static mframe_t soldier_frames_death3[] = {
 	{ai_move, -5, NULL},
 	{ai_move, -5, NULL},
 	{ai_move, -5, NULL},
@@ -1417,14 +1518,15 @@ mframe_t soldier_frames_death3[] = {
 	{ai_move, 0, NULL},
 };
 
-mmove_t soldier_move_death3 = {
+mmove_t soldier_move_death3 =
+{
 	FRAME_death301,
    	FRAME_death345,
    	soldier_frames_death3,
    	soldier_dead
 };
 
-mframe_t soldier_frames_death4[] = {
+static mframe_t soldier_frames_death4[] = {
 	{ai_move, 0, NULL},
 	{ai_move, 0, NULL},
 	{ai_move, 0, NULL},
@@ -1485,14 +1587,15 @@ mframe_t soldier_frames_death4[] = {
 	{ai_move, 0, NULL}
 };
 
-mmove_t soldier_move_death4 = {
+mmove_t soldier_move_death4 =
+{
 	FRAME_death401,
    	FRAME_death453,
    	soldier_frames_death4,
    	soldier_dead2
 };
 
-mframe_t soldier_frames_death5[] = {
+static mframe_t soldier_frames_death5[] = {
 	{ai_move, -5, NULL},
 	{ai_move, -5, NULL},
 	{ai_move, -5, NULL},
@@ -1521,14 +1624,15 @@ mframe_t soldier_frames_death5[] = {
 	{ai_move, 0, NULL}
 };
 
-mmove_t soldier_move_death5 = {
+mmove_t soldier_move_death5 =
+{
 	FRAME_death501,
    	FRAME_death524,
    	soldier_frames_death5,
    	soldier_dead
 };
 
-mframe_t soldier_frames_death6[] = {
+static mframe_t soldier_frames_death6[] = {
 	{ai_move, 0, NULL},
 	{ai_move, 0, NULL},
 	{ai_move, 0, NULL},
@@ -1541,16 +1645,18 @@ mframe_t soldier_frames_death6[] = {
 	{ai_move, 0, NULL}
 };
 
-mmove_t soldier_move_death6 = {
+mmove_t soldier_move_death6 =
+{
 	FRAME_death601,
-   	FRAME_death610,
-   	soldier_frames_death6,
-   	soldier_dead
+	FRAME_death610,
+	soldier_frames_death6,
+	soldier_dead
 };
 
 void
-soldier_die(edict_t *self, edict_t *inflictor /* unused */, edict_t *attacker /* unused */,
-		int damage, vec3_t point /* unused */)
+soldier_die(edict_t *self, edict_t *inflictor /* unused */,
+		edict_t *attacker /* unused */, int damage,
+		vec3_t point /* unused */)
 {
 	int n;
 
@@ -1566,11 +1672,14 @@ soldier_die(edict_t *self, edict_t *inflictor /* unused */, edict_t *attacker /*
 
 		for (n = 0; n < 3; n++)
 		{
-			ThrowGib(self, "models/objects/gibs/sm_meat/tris.md2", damage, GIB_ORGANIC);
+			ThrowGib(self, "models/objects/gibs/sm_meat/tris.md2",
+					damage, GIB_ORGANIC);
 		}
 
-		ThrowGib(self, "models/objects/gibs/chest/tris.md2", damage, GIB_ORGANIC);
-		ThrowHead(self, "models/objects/gibs/head2/tris.md2", damage, GIB_ORGANIC);
+		ThrowGib(self, "models/objects/gibs/chest/tris.md2",
+				damage, GIB_ORGANIC);
+		ThrowHead(self, "models/objects/gibs/head2/tris.md2",
+				damage, GIB_ORGANIC);
 		self->deadflag = DEAD_DEAD;
 		return;
 	}
@@ -1687,7 +1796,7 @@ soldier_duck(edict_t *self, float eta)
 	}
 }
 
-mframe_t soldier_frames_blind[] = {
+static mframe_t soldier_frames_blind[] = {
 	{ai_move, 0, soldier_idle},
 	{ai_move, 0, NULL},
 	{ai_move, 0, NULL},
@@ -1748,6 +1857,13 @@ SP_monster_soldier_x(edict_t *self)
 		return;
 	}
 
+	// Force recaching at next footstep to ensure
+	// that the sound indices are correct.
+	sound_step = 0;
+	sound_step2 = 0;
+	sound_step3 = 0;
+	sound_step4 = 0;
+
 	self->s.modelindex = gi.modelindex("models/monsters/soldier/tris.md2");
 	self->monsterinfo.scale = MODEL_SCALE;
 	VectorSet(self->mins, -16, -16, -24);
