@@ -346,7 +346,7 @@ turret_search(edict_t *self)
 {
 }
 
-mframe_t turret_frames_stand[] = {
+static mframe_t turret_frames_stand[] = {
 	{ai_stand, 0, NULL},
 	{ai_stand, 0, NULL}
 };
@@ -369,7 +369,7 @@ turret_stand(edict_t *self)
 	self->monsterinfo.currentmove = &turret_move_stand;
 }
 
-mframe_t turret_frames_ready_gun[] = {
+static mframe_t turret_frames_ready_gun[] = {
 	{ai_stand, 0, NULL},
 	{ai_stand, 0, NULL},
 	{ai_stand, 0, NULL},
@@ -399,7 +399,7 @@ turret_ready_gun(edict_t *self)
 	self->monsterinfo.currentmove = &turret_move_ready_gun;
 }
 
-mframe_t turret_frames_seek[] = {
+static mframe_t turret_frames_seek[] = {
 	{ai_walk, 0, TurretAim},
 	{ai_walk, 0, TurretAim}
 };
@@ -429,7 +429,7 @@ turret_walk(edict_t *self)
 	}
 }
 
-mframe_t turret_frames_run[] = {
+static mframe_t turret_frames_run[] = {
 	{ai_run, 0, TurretAim},
 	{ai_run, 0, TurretAim}
 };
@@ -653,7 +653,7 @@ TurretFireBlind(edict_t *self)
 	}
 }
 
-mframe_t turret_frames_fire[] = {
+static mframe_t turret_frames_fire[] = {
 	{ai_run, 0, TurretFire},
 	{ai_run, 0, TurretAim},
 	{ai_run, 0, TurretAim},
@@ -668,7 +668,7 @@ mmove_t turret_move_fire = {
 };
 
 /* the blind frames need to aim first */
-mframe_t turret_frames_fire_blind[] = {
+static mframe_t turret_frames_fire_blind[] = {
 	{ai_run, 0, TurretAim},
 	{ai_run, 0, TurretAim},
 	{ai_run, 0, TurretAim},
